
import { AlertTriangle, Zap, ShieldCheck } from 'lucide-react';

interface RiskMatrixProps {
  riskScore: number;
}

const getRiskLevel = (score: number) => {
  if (score <= 30) return { level: 'Low', color: 'bg-green-500' };
  if (score <= 70) return { level: 'Medium', color: 'bg-yellow-500' };
  return { level: 'High', color: 'bg-red-500' };
};

const RiskMatrix: React.FC<RiskMatrixProps> = ({ riskScore }) => {
  const { level, color } = getRiskLevel(riskScore);
  
  const getRiskIcon = () => {
    switch (level) {
      case 'Low':
        return <ShieldCheck className="h-8 w-8 text-green-500" />;
      case 'Medium':
        return <Zap className="h-8 w-8 text-yellow-500" />;
      case 'High':
        return <AlertTriangle className="h-8 w-8 text-red-500" />;
      default:
        return null;
    }
  };

  return (
    <div className="glass-panel p-6">
      <h3 className="text-lg font-semibold mb-6">Risk Matrix</h3>
      
      <div className="mb-6 flex items-center">
        {getRiskIcon()}
        <div className="ml-3">
          <div className="text-2xl font-bold">{level} Risk</div>
          <div className="text-muted-foreground">Risk Score: {riskScore}/100</div>
        </div>
      </div>
      
      <div className="relative h-8 rounded-full bg-muted overflow-hidden mb-6">
        <div 
          className={`absolute top-0 left-0 h-full ${color} transition-all duration-1000`} 
          style={{ width: `${riskScore}%` }}
        />
      </div>
      
      <div className="grid grid-cols-3 gap-2 text-center text-sm">
        <div>
          <div className="h-2 bg-green-500 rounded mb-1"></div>
          <div>Low Risk (0-30)</div>
        </div>
        <div>
          <div className="h-2 bg-yellow-500 rounded mb-1"></div>
          <div>Medium Risk (31-70)</div>
        </div>
        <div>
          <div className="h-2 bg-red-500 rounded mb-1"></div>
          <div>High Risk (71-100)</div>
        </div>
      </div>
      
      <div className="mt-6 p-4 rounded-md bg-muted/50 border border-muted">
        <h4 className="font-medium mb-2">Recommendation</h4>
        {level === 'Low' && (
          <p className="text-sm">
            This client has a low default risk profile. Approval recommended with standard interest rates.
          </p>
        )}
        {level === 'Medium' && (
          <p className="text-sm">
            This client has a moderate default risk. Consider approval with slightly higher interest rates or additional collateral requirements.
          </p>
        )}
        {level === 'High' && (
          <p className="text-sm">
            This client has a high default risk. Approval not recommended without significant collateral or guarantor.
          </p>
        )}
      </div>
    </div>
  );
};

export default RiskMatrix;
